[or-cvs] Crank down the frequency for replacing unchanged descriptors

Nick Mathewson nickm at seul.org
Wed Oct 19 16:21:21 UTC 2005


Update of /home/or/cvsroot/tor/src/or
In directory moria:/tmp/cvs-serv4110/src/or

Modified Files:
	routerlist.c 
Log Message:
Crank down the frequency for replacing unchanged descriptors

Index: routerlist.c
===================================================================
RCS file: /home/or/cvsroot/tor/src/or/routerlist.c,v
retrieving revision 1.348
retrieving revision 1.349
diff -u -d -r1.348 -r1.349
--- routerlist.c	19 Oct 2005 03:08:50 -0000	1.348
+++ routerlist.c	19 Oct 2005 16:21:19 -0000	1.349
@@ -2950,6 +2950,7 @@
       tor_version_as_new_as(r2->platform, "0.1.1.6-alpha"))
     return 0;
 
+  /* r1 should be the one that was published first. */
   if (r1->published_on > r2->published_on) {
     routerinfo_t *ri_tmp = r2;
     r2 = r1;
@@ -2989,8 +2990,8 @@
       (r2->bandwidthcapacity < r1->bandwidthcapacity/2))
     return 0;
 
-  /* Did more than 6 hours pass? */
-  if (r1->published_on + 6*60*60 < r2->published_on)
+  /* Did more than 12 hours pass? */
+  if (r1->published_on + 12*60*60 < r2->published_on)
     return 0;
 
   /* Did uptime fail to increase by approximately the amount we would think,



More information about the tor-commits mailing list